import { createRoot } from 'react-dom/client'
import App from './App.tsx'
import './index.css'

// Performance optimizations
const startTime = performance.now();

// Optimize root element preparation
const rootElement = document.getElementById("root")!;

// Clear loading placeholder efficiently
if (rootElement.children.length > 0) {
  rootElement.innerHTML = '';
}

// Apply critical performance optimizations
if ('requestIdleCallback' in window) {
  // Defer non-critical resource preloading
  requestIdleCallback(() => {
    // Reduce network requests by bundling optimizations
    const fragment = document.createDocumentFragment();
    
    // Preload critical fonts
    const fontPreload = document.createElement('link');
    fontPreload.rel = 'preload';
    fontPreload.as = 'font';
    fontPreload.type = 'font/woff2';
    fontPreload.crossOrigin = 'anonymous';
    fragment.appendChild(fontPreload);
    
    // DNS prefetch for API endpoints
    const dnsPrefetch = document.createElement('link');
    dnsPrefetch.rel = 'dns-prefetch';
    dnsPrefetch.href = 'https://befnviqprxnquhwdsuiw.supabase.co';
    fragment.appendChild(dnsPrefetch);
    
    // Append all at once to minimize reflows
    document.head.appendChild(fragment);
  });
}

// Create and render app immediately
const root = createRoot(rootElement);
root.render(<App />);

// Track performance in development only
if (process.env.NODE_ENV === 'development') {
  requestIdleCallback(() => {
    const totalTime = performance.now() - startTime;
    console.log(`🚀 App initialized in ${totalTime.toFixed(2)}ms`);
  });
}
